@@ -5,7 +5,7 @@ use warnings;
 
 # ABSTRACT: A data processor class
 
-our $VERSION = '1.111380'; # VERSION
+our $VERSION = '1.111450'; # VERSION
 
 use Moose;
 with 'DataFlow::Role::Dumper';
@@ -151,7 +151,7 @@ DataFlow::Proc - A data processor class
 
 =head1 VERSION
 
-version 1.111380
+version 1.111450
 
 =head1 SYNOPSIS
 
@@ -274,10 +274,6 @@ Processes one single scalar (or anything else that can be passed in on scalar,
 such as references or globs), and returns the application of the function
 C<< $self->p->() >> over the item.
 
-=head1 DEPENDENCIES
-
-L<Scalar::Util>
-
 =head1 AUTHOR
 
 Alexei Znamensky <russoz@cpan.org>
