@@ -5,42 +5,57 @@ use warnings;
 
 # ABSTRACT: A encoding conversion processor
 
-our $VERSION = '1.111380'; # VERSION
+our $VERSION = '1.111450'; # VERSION
 
 use Moose;
 extends 'DataFlow::Proc';
 
+use Moose::Util::TypeConstraints 1.01;
+
 use namespace::autoclean;
 use Encode;
 use MooseX::Aliases;
 
-has 'input_encoding' => (
-    'is'        => 'ro',
-    'isa'       => 'Str',
-    'predicate' => 'has_input_encoding',
-    'alias'     => 'from',
+subtype 'Decoder' => as 'CodeRef';
+coerce 'Decoder' => from 'Str' => via {
+    my $encoding = $_;
+    return sub { return decode( $encoding, shift ) };
+};
+
+subtype 'Encoder' => as 'CodeRef';
+coerce 'Encoder' => from 'Str' => via {
+    my $encoding = $_;
+    return sub { return encode( $encoding, shift ) };
+};
+
+has 'input_decoder' => (
+    'is'      => 'ro',
+    'isa'     => 'Decoder',
+    'coerce'  => 1,
+    'lazy'    => 1,
+    'default' => sub {
+        sub { $_[0] }
+    },
+    'alias' => 'from',
 );
 
-has 'output_encoding' => (
-    'is'        => 'ro',
-    'isa'       => 'Str',
-    'predicate' => 'has_output_encoding',
-    'alias'     => 'to',
+has 'output_encoder' => (
+    'is'      => 'ro',
+    'isa'     => 'Encoder',
+    'coerce'  => 1,
+    'lazy'    => 1,
+    'default' => sub {
+        sub { $_[0] }
+    },
+    'alias' => 'to',
 );
 
 has '+p' => (
     'default' => sub {
         my $self = shift;
         return sub {
-            my $item = shift;
-            return $item unless ref($item) eq '';
-            my $internal =
-              $self->has_input_encoding
-              ? decode( $self->input_encoding, $item )
-              : $item;
-            return $self->has_output_encoding
-              ? encode( $self->output_encoding, $internal )
-              : $internal;
+            my $internal = $self->input_decoder->(shift);
+            return $self->output_encoder->($internal);
         };
     },
 );
@@ -61,7 +76,7 @@ DataFlow::Proc::Encoding - A encoding conversion processor
 
 =head1 VERSION
 
-version 1.111380
+version 1.111450
 
 =head1 AUTHOR
 
